<template>
  <zt-combo ref="combo" :placeholder="placeholder" :readonly="readonly" :disabled="disabled" @input-change="onInputChange">
    <zt-tree-selector ref="tree" v-model="treeValue"
                      :idField="idField" :textField="textField" :parentIdField="parentIdField"
                      :disabled="disabled"
                      :url="url" :datas="datas" :simple="simple" :multiple="multiple" :leaf-only="leafOnly"
                      :check-strictly="checkStrictly" :lazy="lazy" :expandLevel="expandLevel"
                      :disabled-filter="disabledFilter" @selected="onSelected"/>
  </zt-combo>

</template>
<script>
  import {debounce} from 'lodash'
  export default {
    name: 'ZtComboTree',
    components: {},
    props: {
      value: [String, Array],
      idField: {
        type: String,
        default: 'id'
      },
      textField: {
        type: String,
        default: 'name'
      },
      parentIdField: {
        type: String,
        default: 'pid'
      },
      url: String,
      datas: [String, Array],
      simple: { // 简单模式
        type: Boolean,
        default: false
      },
      multiple: {
        type: Boolean,
        default: false
      },
      leafOnly: { // 是否只能选择叶子节点
        type: Boolean,
        default: false
      },
      checkStrictly: {
        type: Boolean,
        default: false
      },
      lazy: { // 懒加载子节点
        type: Boolean,
        default: true
      },
      expandLevel: { // 懒加载展开层级
        type: Number,
        default: 0
      },
      disabledFilter: Function, // 可选的节点
      disabled: {
        type: Boolean,
        default: false
      },
      readonly:{
        type: Boolean,
        default: false
      },
      placeholder: String
    },
    data() {
      return {
        treeValue: this.value
      }
    },
    watch: {
      value(val, oldval) { // 传递给tree-selector
        this.treeValue = val
      }
    },
    methods: {
      onInputChange: debounce(function (val) {
        this.$refs.tree.filter(val)
        if ((val || '').length === 0) { // 清空了
          this.$emit('input', '')
          this.$emit('select', null, true)
        }
      }, 1000),
      onSelected(data, isChange) {
        if (!this.multiple) { // 单选
          if (!data) {
            this.$refs.combo.setText('')
          } else {
            this.$refs.combo.setText(data[this.textField]) // combox设置显示值
          }
          this.$refs.combo.close()
        } else { // 多选
          let texts = []
          let values = []
          data.forEach(node => {
            texts.push(node[this.textField])
            values.push(node[this.idField])
          })
          this.$refs.combo.setText(texts.join(','))
        }
        this.$emit('input', this.treeValue) // 这里也可以自己根据data返回自己的
        this.$emit('select', data, isChange)
      }
    }
  }
</script>
<style lang="scss">
  .is-reverse {
    transform: rotate(-180deg);
  }

  .comb-tree {
    height: 250px;
    overflow-y: auto;

    label.el-checkbox {
      margin-right: 8px;
    }

  }
</style>
